#ifndef NEMOTHUMBNAIL_EXPORTS_H
#define NEMOTHUMBNAIL_EXPORTS_H

#if defined(BUILD_NEMO_QML_PLUGIN_NOTIFICATIONS_LIB)
    #define NEMO_QML_PLUGIN_NOTIFICATIONS_EXPORT Q_DECL_EXPORT
#else
    #define NEMO_QML_PLUGIN_NOTIFICATIONS_EXPORT Q_DECL_IMPORT
#endif

#endif // NEMOTHUMBNAIL_EXPORTS_H